Event

Struct Event 

pub struct Event {
    pub id: Option<String>,
    pub object: Option<String>,
    pub api_version: Option<String>,
    pub created: Option<i64>,
    pub livemode: Option<bool>,
    pub pending_webhooks: Option<i64>,
    pub request: Option<Request>,
    pub type_field: Option<String>,
}
Events occur when the state of another API resource changes.

Fields

id: Option<String>object: Option<String>api_version: Option<String>created: Option<i64>livemode: Option<bool>pending_webhooks: Option<i64>request: Option<Request>type_field: Option<String>

Implementations

Source

impl Event

pub async fn async_get(creds: Auth, id: String) -> Result<Self, Error>

Asynchronously retrieves the event with the given ID.

Arguments
  • auth - payup::stripe::Auth::new(client, secret)
  • id - The id of the event you want to retrieve.
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);

// Fetch customer using id
let event = payup::stripe::Event::async_get(auth, "ch_").await?;
pub async fn async_list(creds: Auth) -> Result<Vec<Self>, Error>

Asynchronously returns all stripe Events.

Arguments
  • auth - payup::stripe::Auth::new(client, secret)
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);

// Fetch all customers from stripe
let events = payup::stripe::Event::async_list(auth).await?;
pub fn get(creds: Auth, id: String) -> Result<Self, Error>

Retrieves the event with the given ID.

Arguments
  • auth - payup::stripe::Auth::new(client, secret)
  • id - The id of the event you want to retrieve.
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);

// Fetch customer using id
let event = payup::stripe::Event::get(auth, "ch_")?;
pub fn list(creds: Auth) -> Result<Vec<Self>, Error>

Returns all stripe events.

Arguments
  • auth - payup::stripe::Auth::new(client, secret)
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);

// Fetch all customers from stripe
let events = payup::stripe::Event::list(auth)?;