pub struct File {
pub id: Option<String>,
pub object: Option<String>,
pub created: Option<i64>,
pub expires_at: Option<i64>,
pub filename: Option<String>,
pub links: Option<Links>,
pub purpose: Option<String>,
pub size: Option<i64>,
pub title: Option<String>,
pub type_field: Option<String>,
pub url: Option<String>,
pub file: Option<Vec<u8>>,
}Expand description
Represents a file hosted on Stripe’s servers.
Fields
id: Option<String>object: Option<String>created: Option<i64>expires_at: Option<i64>filename: Option<String>links: Option<Links>purpose: Option<String>size: Option<i64>title: Option<String>type_field: Option<String>url: Option<String>file: Option<Vec<u8>>Implementations
Sourceimpl File
impl File
Sourcepub fn new() -> Self
pub fn new() -> Self
Returns an empty File object
Examples
let mut file = payup::stripe::File::new();
file.title = Some(format!("Title"));Sourcepub async fn async_get(creds: Auth, id: String) -> Result<Self, Error>
pub async fn async_get(creds: Auth, id: String) -> Result<Self, Error>
Asynchronously retrieves a file with the given ID.
Arguments
auth- payup::stripe::Auth::new(client, secret)id- The id of the file you want to retrieve.
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);
// Fetch customer using id
let file = payup::stripe::File::async_get(auth, "ch_").await?;Sourcepub async fn async_list(creds: Auth) -> Result<Vec<Self>, Error>
pub async fn async_list(creds: Auth) -> Result<Vec<Self>, Error>
Asynchronously returns all stripe Files.
Arguments
auth- payup::stripe::Auth::new(client, secret)
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);
// Fetch all customers from stripe
let disputes = payup::stripe::Dispute::async_list(auth).await?;Sourcepub async fn async_post(&self, creds: Auth) -> Result<Self, Error>
pub async fn async_post(&self, creds: Auth) -> Result<Self, Error>
Asynchronously POSTs a new File to the stripe api
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);
let mut file = payup::stripe::File::new();
ley bytes: Vec<u8> = Vec::new();
charge.amount = Some(100);
file.file = Some(bytes);
// The purpose of the uploaded file.
// Possible enum values: account_requirement, additional_verification, business_icon, business_logo, customer_signature, dispute_evidence, identity_document, pci_document, tax_document_user_upload
file.purpose = Some(format!("cust_"));
file = file.post(auth.clone()).await?;Sourcepub fn post(&self, creds: Auth) -> Result<Self, Error>
pub fn post(&self, creds: Auth) -> Result<Self, Error>
POSTs a new File to the stripe api
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);
let mut file = payup::stripe::File::new();
ley bytes: Vec<u8> = Vec::new();
charge.amount = Some(100);
file.file = Some(bytes);
// The purpose of the uploaded file.
// Possible enum values: account_requirement, additional_verification, business_icon, business_logo, customer_signature, dispute_evidence, identity_document, pci_document, tax_document_user_upload
file.purpose = Some(format!("cust_"));
file = file.post(auth.clone())?;Sourcepub fn get(creds: Auth, id: String) -> Result<Self, Error>
pub fn get(creds: Auth, id: String) -> Result<Self, Error>
Retrieves the dispute with the given ID.
Arguments
auth- payup::stripe::Auth::new(client, secret)id- The id of the dispute you want to retrieve.
Examples
// Create the Authentication refererence
let auth = payup::stripe::Auth::new(client, secret);
// Fetch customer using id
let dispute = payup::stripe::Dispute::get(auth, "ch_")?;Trait Implementations
Sourceimpl<'de> Deserialize<'de> for File
impl<'de> Deserialize<'de> for File
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more